@@ -202,7 +202,7 @@ def read_and_convert_heatseq_probes(path: str) -> pd.DataFrame:
         if original_len != len(design):
             log.info('%d/%d probes left after merging probes by ID', len(design), original_len)
         #reset index to turn id into column again
-        design.reset_index(inplace=True)  
+        design.reset_index(inplace=True)
 
         #reorder and extract columns
         design = design[probe_columns]
@@ -273,6 +273,15 @@ def process_probe_design(design: pd.DataFrame, reference_type: str = 'genome') -
     design.loc[design['strand'] == '-', 'probe_start'] = design.loc[design['strand'] == '-', 'target_start'] - design.loc[design['strand'] == '-', 'second_primer_5to3'].str.len()
     design.loc[design['strand'] == '+', 'probe_end'] = design.loc[design['strand'] == '+', 'target_end'] + design.loc[design['strand'] == '+', 'second_primer_5to3'].str.len()
     design.loc[design['strand'] == '-', 'probe_end'] = design.loc[design['strand'] == '-', 'target_end'] + design.loc[design['strand'] == '-', 'first_primer_5to3'].str.len()
+
+    design = design.astype(
+        {
+            'probe_start': int,
+            'probe_end': int,
+        },
+        errors = 'raise'
+    )
+
     design['target_start_0'] = design['target_start'] - 1   # we have 1-based coords now
     design['probe_start_0'] = design['probe_start'] - 1   # we have 1-based coords now
     design['capture_size'] = design['probe_end'] - design['probe_start_0']
@@ -345,7 +354,7 @@ def read_sample_info(path: str) -> pd.DataFrame:
         non_target_columns = [c for c in sample_infos.columns if c != 'Target']
         sample_infos.set_index(non_target_columns, inplace = True) #this needs need to be all unstacked columns
         #stack each column (only Target actually)
-        sample_infos = sample_infos.apply(lambda col: col.apply(pd.Series).stack(), axis=0) 
+        sample_infos = sample_infos.apply(lambda col: col.apply(pd.Series).stack(), axis=0)
         #turn multilevel index back into columns
         sample_infos.reset_index(inplace = True)
         #drop Targets column and target index column generated by reset_index
@@ -513,7 +522,7 @@ def read_snps_txt(path: str, reference_type: str = 'genome') -> pd.DataFrame:
             errors = 'raise'
         )
 
-        # #chr should always start with chr    
+        # #chr should always start with chr
         # if reference_type == 'genome':
         #     snps.loc[~snps['chr'].str.startswith('chr'), 'chr'] = ['chr' + c for c in snps.loc[~snps['chr'].str.startswith('chr'), 'chr']]
 
